@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: LDAP protocol handler used with Net::LDAP::SimpleServer
 
-our $VERSION = '0.0.17';    # VERSION
+our $VERSION = '0.0.18';    # VERSION
 
 use Net::LDAP::Server;
 use base 'Net::LDAP::Server';
@@ -40,7 +40,7 @@ sub _make_result {
 sub new {
     my $class  = shift;
     my $params = shift || croak 'Must pass parameters!';
-    my $self   = $class->SUPER::new( $params->{input}, $params->{output} );
+    my $self   = $class->SUPER::new( $params->{sock} );
 
     croak 'Parameter must be a HASHREF' unless reftype($params) eq 'HASH';
     croak 'Must pass option {store}' unless exists $params->{store};
@@ -138,11 +138,11 @@ sub search {
 
 1;    # Magic true value required at end of module
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -150,7 +150,7 @@ Net::LDAP::SimpleServer::ProtocolHandler - LDAP protocol handler used with Net::
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 SYNOPSIS
 
@@ -208,7 +208,7 @@ Alexei Znamensky <russoz@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Alexei Znamensky.
+This software is copyright (c) 2012 - 2017 by Alexei Znamensky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -242,8 +242,3 @@ SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
 DAMAGES.
 
 =cut
-
-
-__END__
-
-
